@@ -141,7 +141,7 @@ EAPI const Eo_Class *elm_entry_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_scrollable_set(Eina_Bool scroll);
+EOAPI void elm_obj_entry_scrollable_set(Eina_Bool scroll);
 
 /**
  * @brief Get the scrollable state of the entry
@@ -153,7 +153,7 @@ EOAPI void  elm_obj_entry_scrollable_set(Eina_Bool scroll);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_scrollable_get(void);
+EOAPI Eina_Bool elm_obj_entry_scrollable_get(void);
 
 /**
  * @brief Set the attribute to show the input panel in case of only an user's
@@ -167,7 +167,7 @@ EOAPI Eina_Bool  elm_obj_entry_scrollable_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_show_on_demand_set(Eina_Bool ondemand);
+EOAPI void elm_obj_entry_input_panel_show_on_demand_set(Eina_Bool ondemand);
 
 /**
  * @brief Get the attribute to show the input panel in case of only an user's
@@ -180,7 +180,7 @@ EOAPI void  elm_obj_entry_input_panel_show_on_demand_set(Eina_Bool ondemand);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_input_panel_show_on_demand_get(void);
+EOAPI Eina_Bool elm_obj_entry_input_panel_show_on_demand_get(void);
 
 /**
  * @brief This disables the entry's contextual (longpress) menu.
@@ -189,7 +189,7 @@ EOAPI Eina_Bool  elm_obj_entry_input_panel_show_on_demand_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_context_menu_disabled_set(Eina_Bool disabled);
+EOAPI void elm_obj_entry_context_menu_disabled_set(Eina_Bool disabled);
 
 /**
  * @brief This returns whether the entry's contextual (longpress) menu is
@@ -199,7 +199,7 @@ EOAPI void  elm_obj_entry_context_menu_disabled_set(Eina_Bool disabled);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_context_menu_disabled_get(void);
+EOAPI Eina_Bool elm_obj_entry_context_menu_disabled_get(void);
 
 /**
  * @brief Control pasting of text and images for the widget.
@@ -216,7 +216,7 @@ EOAPI Eina_Bool  elm_obj_entry_context_menu_disabled_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cnp_mode_set(Elm_Cnp_Mode cnp_mode);
+EOAPI void elm_obj_entry_cnp_mode_set(Elm_Cnp_Mode cnp_mode);
 
 /**
  * @brief Getting elm_entry text paste/drop mode.
@@ -229,7 +229,7 @@ EOAPI void  elm_obj_entry_cnp_mode_set(Elm_Cnp_Mode cnp_mode);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Cnp_Mode  elm_obj_entry_cnp_mode_get(void);
+EOAPI Elm_Cnp_Mode elm_obj_entry_cnp_mode_get(void);
 
 /**
  * @brief Text format used to load and save the file, which could be plain text
@@ -248,7 +248,7 @@ EOAPI Elm_Cnp_Mode  elm_obj_entry_cnp_mode_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_file_text_format_set(Elm_Text_Format format);
+EOAPI void elm_obj_entry_file_text_format_set(Elm_Text_Format format);
 
 /**
  * @brief Set the language mode of the input panel.
@@ -259,7 +259,7 @@ EOAPI void  elm_obj_entry_file_text_format_set(Elm_Text_Format format);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_language_set(Elm_Input_Panel_Lang lang);
+EOAPI void elm_obj_entry_input_panel_language_set(Elm_Input_Panel_Lang lang);
 
 /**
  * @brief Get the language mode of the input panel.
@@ -268,7 +268,7 @@ EOAPI void  elm_obj_entry_input_panel_language_set(Elm_Input_Panel_Lang lang);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Input_Panel_Lang  elm_obj_entry_input_panel_language_get(void);
+EOAPI Elm_Input_Panel_Lang elm_obj_entry_input_panel_language_get(void);
 
 /**
  * @brief This disabled the entry's selection handlers.
@@ -277,7 +277,7 @@ EOAPI Elm_Input_Panel_Lang  elm_obj_entry_input_panel_language_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_selection_handler_disabled_set(Eina_Bool disabled);
+EOAPI void elm_obj_entry_selection_handler_disabled_set(Eina_Bool disabled);
 
 /**
  * @brief This returns whether the entry's selection handlers are disabled.
@@ -286,7 +286,7 @@ EOAPI void  elm_obj_entry_selection_handler_disabled_set(Eina_Bool disabled);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_selection_handler_disabled_get(void);
+EOAPI Eina_Bool elm_obj_entry_selection_handler_disabled_get(void);
 
 /**
  * @brief Set the input panel layout variation of the entry
@@ -297,7 +297,7 @@ EOAPI Eina_Bool  elm_obj_entry_selection_handler_disabled_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_layout_variation_set(int variation);
+EOAPI void elm_obj_entry_input_panel_layout_variation_set(int variation);
 
 /**
  * @brief Get the input panel layout variation of the entry
@@ -308,7 +308,7 @@ EOAPI void  elm_obj_entry_input_panel_layout_variation_set(int variation);
  *
  * @ingroup Elm_Entry
  */
-EOAPI int  elm_obj_entry_input_panel_layout_variation_get(void);
+EOAPI int elm_obj_entry_input_panel_layout_variation_get(void);
 
 /**
  * @brief Set the autocapitalization type on the immodule.
@@ -317,7 +317,7 @@ EOAPI int  elm_obj_entry_input_panel_layout_variation_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_autocapital_type_set(Elm_Autocapital_Type autocapital_type);
+EOAPI void elm_obj_entry_autocapital_type_set(Elm_Autocapital_Type autocapital_type);
 
 /**
  * @brief Get the autocapitalization type on the immodule.
@@ -326,7 +326,7 @@ EOAPI void  elm_obj_entry_autocapital_type_set(Elm_Autocapital_Type autocapital_
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Autocapital_Type  elm_obj_entry_autocapital_type_get(void);
+EOAPI Elm_Autocapital_Type elm_obj_entry_autocapital_type_get(void);
 
 /**
  * @brief Sets if the entry is to be editable or not.
@@ -345,7 +345,7 @@ EOAPI Elm_Autocapital_Type  elm_obj_entry_autocapital_type_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_editable_set(Eina_Bool editable);
+EOAPI void elm_obj_entry_editable_set(Eina_Bool editable);
 
 /**
  * @brief Get whether the entry is editable or not.
@@ -355,7 +355,7 @@ EOAPI void  elm_obj_entry_editable_set(Eina_Bool editable);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_editable_get(void);
+EOAPI Eina_Bool elm_obj_entry_editable_get(void);
 
 /**
  * @brief Set the style that the hover should use
@@ -369,7 +369,7 @@ EOAPI Eina_Bool  elm_obj_entry_editable_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_anchor_hover_style_set(const char *style);
+EOAPI void elm_obj_entry_anchor_hover_style_set(const char *style);
 
 /**
  * @brief Get the style that the hover should use.
@@ -378,7 +378,7 @@ EOAPI void  elm_obj_entry_anchor_hover_style_set(const char *style);
  *
  * @ingroup Elm_Entry
  */
-EOAPI const char * elm_obj_entry_anchor_hover_style_get(void);
+EOAPI const char *elm_obj_entry_anchor_hover_style_get(void);
 
 /**
  * @brief Sets the entry to single line mode.
@@ -396,7 +396,7 @@ EOAPI const char * elm_obj_entry_anchor_hover_style_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_single_line_set(Eina_Bool single_line);
+EOAPI void elm_obj_entry_single_line_set(Eina_Bool single_line);
 
 /**
  * @brief Get whether the entry is set to be single line.
@@ -405,7 +405,7 @@ EOAPI void  elm_obj_entry_single_line_set(Eina_Bool single_line);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_single_line_get(void);
+EOAPI Eina_Bool elm_obj_entry_single_line_get(void);
 
 /**
  * @brief Sets the entry to password mode.
@@ -417,7 +417,7 @@ EOAPI Eina_Bool  elm_obj_entry_single_line_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_password_set(Eina_Bool password);
+EOAPI void elm_obj_entry_password_set(Eina_Bool password);
 
 /**
  * @brief Get whether the entry is set to password mode.
@@ -426,7 +426,7 @@ EOAPI void  elm_obj_entry_password_set(Eina_Bool password);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_password_get(void);
+EOAPI Eina_Bool elm_obj_entry_password_get(void);
 
 /**
  * @brief Set the return key on the input panel to be disabled.
@@ -436,7 +436,7 @@ EOAPI Eina_Bool  elm_obj_entry_password_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_return_key_disabled_set(Eina_Bool disabled);
+EOAPI void elm_obj_entry_input_panel_return_key_disabled_set(Eina_Bool disabled);
 
 /**
  * @brief Get whether the return key on the input panel should be disabled or
@@ -446,7 +446,7 @@ EOAPI void  elm_obj_entry_input_panel_return_key_disabled_set(Eina_Bool disabled
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_input_panel_return_key_disabled_get(void);
+EOAPI Eina_Bool elm_obj_entry_input_panel_return_key_disabled_get(void);
 
 /**
  * @brief This sets the entry object to 'autosave' the loaded text file or not.
@@ -455,7 +455,7 @@ EOAPI Eina_Bool  elm_obj_entry_input_panel_return_key_disabled_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_autosave_set(Eina_Bool auto_save);
+EOAPI void elm_obj_entry_autosave_set(Eina_Bool auto_save);
 
 /**
  * @brief This gets the entry object's 'autosave' status.
@@ -464,7 +464,7 @@ EOAPI void  elm_obj_entry_autosave_set(Eina_Bool auto_save);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_autosave_get(void);
+EOAPI Eina_Bool elm_obj_entry_autosave_get(void);
 
 /**
  * @brief Set the parent of the hover popup
@@ -476,7 +476,7 @@ EOAPI Eina_Bool  elm_obj_entry_autosave_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_anchor_hover_parent_set(Evas_Object *parent);
+EOAPI void elm_obj_entry_anchor_hover_parent_set(Evas_Object *parent);
 
 /**
  * @brief Get the parent of the hover popup
@@ -488,7 +488,7 @@ EOAPI void  elm_obj_entry_anchor_hover_parent_set(Evas_Object *parent);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Evas_Object * elm_obj_entry_anchor_hover_parent_get(void);
+EOAPI Evas_Object *elm_obj_entry_anchor_hover_parent_get(void);
 
 /**
  * @brief Set whether the entry should allow to use the text prediction.
@@ -498,7 +498,7 @@ EOAPI Evas_Object * elm_obj_entry_anchor_hover_parent_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_prediction_allow_set(Eina_Bool prediction);
+EOAPI void elm_obj_entry_prediction_allow_set(Eina_Bool prediction);
 
 /**
  * @brief Get whether the entry should allow to use the text prediction.
@@ -507,7 +507,7 @@ EOAPI void  elm_obj_entry_prediction_allow_set(Eina_Bool prediction);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_prediction_allow_get(void);
+EOAPI Eina_Bool elm_obj_entry_prediction_allow_get(void);
 
 /**
  * @brief Sets the input hint which allows input methods to fine-tune their
@@ -517,7 +517,7 @@ EOAPI Eina_Bool  elm_obj_entry_prediction_allow_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_hint_set(Elm_Input_Hints hints);
+EOAPI void elm_obj_entry_input_hint_set(Elm_Input_Hints hints);
 
 /**
  * @brief Gets the value of input hint.
@@ -526,7 +526,7 @@ EOAPI void  elm_obj_entry_input_hint_set(Elm_Input_Hints hints);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Input_Hints  elm_obj_entry_input_hint_get(void);
+EOAPI Elm_Input_Hints elm_obj_entry_input_hint_get(void);
 
 /**
  * @brief Set the input panel layout of the entry.
@@ -535,7 +535,7 @@ EOAPI Elm_Input_Hints  elm_obj_entry_input_hint_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_layout_set(Elm_Input_Panel_Layout layout);
+EOAPI void elm_obj_entry_input_panel_layout_set(Elm_Input_Panel_Layout layout);
 
 /**
  * @brief Get the input panel layout of the entry.
@@ -544,7 +544,7 @@ EOAPI void  elm_obj_entry_input_panel_layout_set(Elm_Input_Panel_Layout layout);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Input_Panel_Layout  elm_obj_entry_input_panel_layout_get(void);
+EOAPI Elm_Input_Panel_Layout elm_obj_entry_input_panel_layout_get(void);
 
 /**
  * @brief Set the "return" key type. This type is used to set string or icon on
@@ -556,7 +556,7 @@ EOAPI Elm_Input_Panel_Layout  elm_obj_entry_input_panel_layout_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_return_key_type_set(Elm_Input_Panel_Return_Key_Type return_key_type);
+EOAPI void elm_obj_entry_input_panel_return_key_type_set(Elm_Input_Panel_Return_Key_Type return_key_type);
 
 /**
  * @brief Get the "return" key type.
@@ -565,7 +565,7 @@ EOAPI void  elm_obj_entry_input_panel_return_key_type_set(Elm_Input_Panel_Return
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Input_Panel_Return_Key_Type  elm_obj_entry_input_panel_return_key_type_get(void);
+EOAPI Elm_Input_Panel_Return_Key_Type elm_obj_entry_input_panel_return_key_type_get(void);
 
 /**
  * @brief Sets the attribute to show the input panel automatically.
@@ -575,7 +575,7 @@ EOAPI Elm_Input_Panel_Return_Key_Type  elm_obj_entry_input_panel_return_key_type
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_enabled_set(Eina_Bool enabled);
+EOAPI void elm_obj_entry_input_panel_enabled_set(Eina_Bool enabled);
 
 /**
  * @brief Get the attribute to show the input panel automatically.
@@ -585,7 +585,7 @@ EOAPI void  elm_obj_entry_input_panel_enabled_set(Eina_Bool enabled);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_input_panel_enabled_get(void);
+EOAPI Eina_Bool elm_obj_entry_input_panel_enabled_get(void);
 
 /**
  * @brief Set the line wrap type to use on multi-line entries.
@@ -602,7 +602,7 @@ EOAPI Eina_Bool  elm_obj_entry_input_panel_enabled_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_line_wrap_set(Elm_Wrap_Type wrap);
+EOAPI void elm_obj_entry_line_wrap_set(Elm_Wrap_Type wrap);
 
 /**
  * @brief Get the wrap mode the entry was set to use.
@@ -611,7 +611,7 @@ EOAPI void  elm_obj_entry_line_wrap_set(Elm_Wrap_Type wrap);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Elm_Wrap_Type  elm_obj_entry_line_wrap_get(void);
+EOAPI Elm_Wrap_Type elm_obj_entry_line_wrap_get(void);
 
 /**
  * @brief Sets the cursor position in the entry to the given value
@@ -623,7 +623,7 @@ EOAPI Elm_Wrap_Type  elm_obj_entry_line_wrap_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_pos_set(int pos);
+EOAPI void elm_obj_entry_cursor_pos_set(int pos);
 
 /**
  * @brief Get the current position of the cursor in the entry.
@@ -632,7 +632,7 @@ EOAPI void  elm_obj_entry_cursor_pos_set(int pos);
  *
  * @ingroup Elm_Entry
  */
-EOAPI int  elm_obj_entry_cursor_pos_get(void);
+EOAPI int elm_obj_entry_cursor_pos_get(void);
 
 /**
  * @brief Sets the visibility of the left-side widget of the entry, set by @ref
@@ -643,13 +643,13 @@ EOAPI int  elm_obj_entry_cursor_pos_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_icon_visible_set(Eina_Bool setting);
+EOAPI void elm_obj_entry_icon_visible_set(Eina_Bool setting);
 
 /** This moves the cursor to the end of the current line.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_line_end_set(void);
+EOAPI void elm_obj_entry_cursor_line_end_set(void);
 
 /**
  * @brief This selects a region of text within the entry.
@@ -661,7 +661,7 @@ EOAPI void  elm_obj_entry_cursor_line_end_set(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_select_region_set(int start, int end);
+EOAPI void elm_obj_entry_select_region_set(int start, int end);
 
 /**
  * @brief Set whether the return key on the input panel is disabled
@@ -676,7 +676,7 @@ EOAPI void  elm_obj_entry_select_region_set(int start, int end);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_return_key_autoenabled_set(Eina_Bool enabled);
+EOAPI void elm_obj_entry_input_panel_return_key_autoenabled_set(Eina_Bool enabled);
 
 /**
  * @brief Sets the visibility of the end widget of the entry, set by @ref
@@ -686,25 +686,25 @@ EOAPI void  elm_obj_entry_input_panel_return_key_autoenabled_set(Eina_Bool enabl
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_end_visible_set(Eina_Bool setting);
+EOAPI void elm_obj_entry_end_visible_set(Eina_Bool setting);
 
 /** This moves the cursor to the beginning of the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_begin_set(void);
+EOAPI void elm_obj_entry_cursor_begin_set(void);
 
 /** This moves the cursor to the beginning of the current line.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_line_begin_set(void);
+EOAPI void elm_obj_entry_cursor_line_begin_set(void);
 
 /** This moves the cursor to the end of the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_end_set(void);
+EOAPI void elm_obj_entry_cursor_end_set(void);
 
 /**
  * @brief Returns the actual textblock object of the entry.
@@ -731,7 +731,7 @@ EOAPI void  elm_obj_entry_cursor_end_set(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Evas_Object * elm_obj_entry_textblock_get(void);
+EOAPI Evas_Object *elm_obj_entry_textblock_get(void);
 
 /**
  * @brief This function returns the geometry of the cursor.
@@ -746,7 +746,7 @@ EOAPI Evas_Object * elm_obj_entry_textblock_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_geometry_get(Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+EOAPI Eina_Bool elm_obj_entry_cursor_geometry_get(Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Returns the input method context of the entry.
@@ -758,7 +758,7 @@ EOAPI Eina_Bool  elm_obj_entry_cursor_geometry_get(Evas_Coord *x, Evas_Coord *y,
  *
  * @ingroup Elm_Entry
  */
-EOAPI void * elm_obj_entry_imf_context_get(void);
+EOAPI void *elm_obj_entry_imf_context_get(void);
 
 /**
  * @brief Get whether a format node exists at the current cursor position.
@@ -770,7 +770,7 @@ EOAPI void * elm_obj_entry_imf_context_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_is_format_get(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_is_format_get(void);
 
 /**
  * @brief Get the character pointed by the cursor at its current position.
@@ -782,7 +782,7 @@ EOAPI Eina_Bool  elm_obj_entry_cursor_is_format_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI char * elm_obj_entry_cursor_content_get(void);
+EOAPI char *elm_obj_entry_cursor_content_get(void);
 
 /**
  * @brief Get any selected text within the entry.
@@ -797,19 +797,19 @@ EOAPI char * elm_obj_entry_cursor_content_get(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI const char * elm_obj_entry_selection_get(void);
+EOAPI const char *elm_obj_entry_selection_get(void);
 
 /** Get if the current cursor position holds a visible format node.
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_is_visible_format_get(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_is_visible_format_get(void);
 
 /** This moves the cursor one place to the left within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_prev(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_prev(void);
 
 /** Remove the style in the top of user style stack.
  *
@@ -817,7 +817,7 @@ EOAPI Eina_Bool  elm_obj_entry_cursor_prev(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_text_style_user_pop(void);
+EOAPI void elm_obj_entry_text_style_user_pop(void);
 
 /**
  * @brief This prepends a custom item provider to the list for that entry
@@ -828,7 +828,7 @@ EOAPI void  elm_obj_entry_text_style_user_pop(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_item_provider_prepend(Elm_Entry_Item_Provider_Cb func, void *data);
+EOAPI void elm_obj_entry_item_provider_prepend(Elm_Entry_Item_Provider_Cb func, void *data);
 
 /**
  * @brief Show the input panel (virtual keyboard) based on the input panel
@@ -841,7 +841,7 @@ EOAPI void  elm_obj_entry_item_provider_prepend(Elm_Entry_Item_Provider_Cb func,
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_show(void);
+EOAPI void elm_obj_entry_input_panel_show(void);
 
 /**
  * @brief Reset the input method context of the entry if needed.
@@ -852,7 +852,7 @@ EOAPI void  elm_obj_entry_input_panel_show(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_imf_context_reset(void);
+EOAPI void elm_obj_entry_imf_context_reset(void);
 
 /**
  * @brief Forces calculation of the entry size and text layouting.
@@ -862,7 +862,7 @@ EOAPI void  elm_obj_entry_imf_context_reset(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_calc_force(void);
+EOAPI void elm_obj_entry_calc_force(void);
 
 /**
  * @brief Ends the hover popup in the entry
@@ -873,33 +873,33 @@ EOAPI void  elm_obj_entry_calc_force(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_anchor_hover_end(void);
+EOAPI void elm_obj_entry_anchor_hover_end(void);
 
 /** This begins a selection within the entry as though the user were holding
  * down the mouse button to make a selection.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_selection_begin(void);
+EOAPI void elm_obj_entry_cursor_selection_begin(void);
 
 /** This moves the cursor one line down within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_down(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_down(void);
 
 /** This function writes any changes made to the file set with @ref
  * elm_entry_file_set.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_file_save(void);
+EOAPI void elm_obj_entry_file_save(void);
 
 /** This executes a "copy" action on the selected text in the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_selection_copy(void);
+EOAPI void elm_obj_entry_selection_copy(void);
 
 /**
  * @brief Push the style to the top of user style stack. If there is styles in
@@ -914,7 +914,7 @@ EOAPI void  elm_obj_entry_selection_copy(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_text_style_user_push(const char *style);
+EOAPI void elm_obj_entry_text_style_user_push(const char *style);
 
 /**
  * @brief This removes a custom item provider to the list for that entry
@@ -926,7 +926,7 @@ EOAPI void  elm_obj_entry_text_style_user_push(const char *style);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_item_provider_remove(Elm_Entry_Item_Provider_Cb func, void *data);
+EOAPI void elm_obj_entry_item_provider_remove(Elm_Entry_Item_Provider_Cb func, void *data);
 
 /**
  * @brief Get the style on the top of user style stack.
@@ -937,7 +937,7 @@ EOAPI void  elm_obj_entry_item_provider_remove(Elm_Entry_Item_Provider_Cb func,
  *
  * @ingroup Elm_Entry
  */
-EOAPI const char * elm_obj_entry_text_style_user_peek(void);
+EOAPI const char *elm_obj_entry_text_style_user_peek(void);
 
 /**
  * @brief This clears and frees the items in a entry's contextual (longpress)
@@ -947,13 +947,13 @@ EOAPI const char * elm_obj_entry_text_style_user_peek(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_context_menu_clear(void);
+EOAPI void elm_obj_entry_context_menu_clear(void);
 
 /** This moves the cursor one line up within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_up(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_up(void);
 
 /**
  * @brief Inserts the given text into the entry at the current cursor position.
@@ -974,7 +974,7 @@ EOAPI Eina_Bool  elm_obj_entry_cursor_up(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_insert(const char *entry);
+EOAPI void elm_obj_entry_insert(const char *entry);
 
 /**
  * @brief Set the input panel-specific data to deliver to the input panel.
@@ -987,7 +987,7 @@ EOAPI void  elm_obj_entry_insert(const char *entry);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_imdata_set(const void *data, int len);
+EOAPI void elm_obj_entry_input_panel_imdata_set(const void *data, int len);
 
 /**
  * @brief Get the specific data of the current input panel.
@@ -996,25 +996,25 @@ EOAPI void  elm_obj_entry_input_panel_imdata_set(const void *data, int len);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_imdata_get(void *data, int *len);
+EOAPI void elm_obj_entry_input_panel_imdata_get(void *data, int *len);
 
 /** This executes a "paste" action in the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_selection_paste(void);
+EOAPI void elm_obj_entry_selection_paste(void);
 
 /** This moves the cursor one place to the right within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_cursor_next(void);
+EOAPI Eina_Bool elm_obj_entry_cursor_next(void);
 
 /** This drops any existing text selection within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_select_none(void);
+EOAPI void elm_obj_entry_select_none(void);
 
 /**
  * @brief Hide the input panel (virtual keyboard).
@@ -1026,26 +1026,26 @@ EOAPI void  elm_obj_entry_select_none(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_input_panel_hide(void);
+EOAPI void elm_obj_entry_input_panel_hide(void);
 
 /** This selects all text within the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_select_all(void);
+EOAPI void elm_obj_entry_select_all(void);
 
 /** This ends a selection within the entry as though the user had just released
  * the mouse button while making a selection.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_cursor_selection_end(void);
+EOAPI void elm_obj_entry_cursor_selection_end(void);
 
 /** This executes a "cut" action on the selected text in the entry.
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_selection_cut(void);
+EOAPI void elm_obj_entry_selection_cut(void);
 
 /**
  * @brief Get whether the entry is empty.
@@ -1056,7 +1056,7 @@ EOAPI void  elm_obj_entry_selection_cut(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool  elm_obj_entry_is_empty(void);
+EOAPI Eina_Bool elm_obj_entry_is_empty(void);
 
 /**
  * @brief Remove a markup filter from the list
@@ -1068,7 +1068,7 @@ EOAPI Eina_Bool  elm_obj_entry_is_empty(void);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_markup_filter_remove(Elm_Entry_Filter_Cb func, void *data);
+EOAPI void elm_obj_entry_markup_filter_remove(Elm_Entry_Filter_Cb func, void *data);
 
 /**
  * @brief This appends a custom item provider to the list for that entry
@@ -1086,7 +1086,7 @@ EOAPI void  elm_obj_entry_markup_filter_remove(Elm_Entry_Filter_Cb func, void *d
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_item_provider_append(Elm_Entry_Item_Provider_Cb func, void *data);
+EOAPI void elm_obj_entry_item_provider_append(Elm_Entry_Item_Provider_Cb func, void *data);
 
 /**
  * @brief Append a markup filter function for text inserted in the entry
@@ -1103,7 +1103,7 @@ EOAPI void  elm_obj_entry_item_provider_append(Elm_Entry_Item_Provider_Cb func,
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_markup_filter_append(Elm_Entry_Filter_Cb func, void *data);
+EOAPI void elm_obj_entry_markup_filter_append(Elm_Entry_Filter_Cb func, void *data);
 
 /**
  * @brief Appends @c str to the text of the entry.
@@ -1119,7 +1119,7 @@ EOAPI void  elm_obj_entry_markup_filter_append(Elm_Entry_Filter_Cb func, void *d
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_append(const char *str);
+EOAPI void elm_obj_entry_append(const char *str);
 
 /**
  * @brief This adds an item to the entry's contextual menu.
@@ -1140,7 +1140,7 @@ EOAPI void  elm_obj_entry_append(const char *str);
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_context_menu_item_add(const char *label, const char *icon_file, Elm_Icon_Type icon_type, Evas_Smart_Cb func, const void *data);
+EOAPI void elm_obj_entry_context_menu_item_add(const char *label, const char *icon_file, Elm_Icon_Type icon_type, Evas_Smart_Cb func, const void *data);
 
 /**
  * @brief Prepend a markup filter function for text inserted in the entry
@@ -1151,10 +1151,8 @@ EOAPI void  elm_obj_entry_context_menu_item_add(const char *label, const char *i
  *
  * @ingroup Elm_Entry
  */
-EOAPI void  elm_obj_entry_markup_filter_prepend(Elm_Entry_Filter_Cb func, void *data);
+EOAPI void elm_obj_entry_markup_filter_prepend(Elm_Entry_Filter_Cb func, void *data);
 
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ACTIVATED;
 EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CHANGED_USER;
@@ -1177,16 +1175,6 @@ EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_UP;
 EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED_MANUAL;
 
-/**
- * No description
- */
-#define ELM_ENTRY_EVENT_LANGUAGE_CHANGED (&(_ELM_ENTRY_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_ENTRY_EVENT_ACCESS_CHANGED (&(_ELM_ENTRY_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
